@@ -1,7 +1,10 @@
-VERSION = '0.4.0'
+# coding=utf-8
+
+VERSION = '0.4.2'
 
 
 AVAILABLE_LOCALES = [
+    'bg_BG',
     'cs_CZ',
     'de_DE',
     'dk_DK',
@@ -17,10 +20,15 @@ AVAILABLE_LOCALES = [
     'hi_IN',
     'it_IT',
     'ko_KR',
+    'lt_LT',
+    'lv_LV',
+    'nl_NL',
     'pl_PL',
     'pt_BR',
     'ru_RU',
+    'sl_SI',
     'zh_CN',
+    'zh_TW'
 ]
 
 DEFAULT_LOCALE = 'en_US'
