@@ -1,3 +1,5 @@
+# coding=utf-8
+
 from __future__ import unicode_literals
 from ..phone_number import Provider as PhoneNumberProvider
 
@@ -14,5 +16,5 @@ class Provider(PhoneNumberProvider):
         '0#### ######',
         '0#### #####',
         '(0####) ######',
-        '(0####) #####'
+        '(0####) #####',
     )
